<?php defined("SYSPATH") or die("No direct script access.");
/**
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2011 Bharat Mediratta
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 */
class Admin_Tag_Graph_Controller extends Admin_Controller {
  public function index() {
    $view = new Admin_View("admin.html");
    $view->content = new View("admin_tag_graph.html");
    $view->content->form = $this->_get_admin_form();

    print $view;
  }

  public function edit() {
    access::verify_csrf();

    $form = $this->_get_admin_form();
    if ($form->validate()) {
      $options = $form->tag_graph_options;
      $valid = true;
      if (preg_match("/^#?([0-9a-f]{1,2}){3}$/i", $options->tagcolor->value) == 0) {
        $options->tagcolor->add_error("not valid HEX color value", 1);
        $valid = false;
      }
	  if (preg_match("/^#?([0-9a-f]{1,2}){3}$/i", $options->mouseover->value) == 0) {
        $options->mouseover->add_error("not valid HEX color value", 1);
        $valid = false;
      }
      if ($valid) {
	    module::set_var("tag_graph", "title", $options->title->value);
		module::set_var("tag_graph", "sort_order", $options->sort_order->value);
        module::set_var("tag_graph", "tagcolor", $options->tagcolor->value);
        module::set_var("tag_graph", "mouseover", $options->mouseover->value);
        module::set_var("tag_graph", "show_above", $options->show_above->value);
		module::set_var("tag_graph", "show_below", $options->show_below->value);
		module::set_var("tag_graph", "height", $options->height->value);
        message::success(t("Tag graph options updated successfully"));
        url::redirect("admin/tag_graph");
      }
    }

    $view = new Admin_View("admin.html");
    $view->content = new View("admin_tag_graph.html");
    $view->content->form = $form;

    print $view;
  }

  private function _get_admin_form() {
    $form = new Forge("admin/tag_graph/edit", "", "post",
                      array("id" => "g-tag-graph-admin-form"));
    $group = $form->group("tag_graph_options")->label(t("Settings"));
    $group->input("title")    ->label(t("Title of block"))
      ->value(module::get_var("tag_graph", "title", "Tag Graph"))
      ->rules("required");
    $group->dropdown("sort_order")
      ->label(t("Sort order"))
      ->options(array("ASCEND" => t("Ascending"),
                      "DECEND" => t("Descending"),
					  "ALPHA" => t("Alphabetical")))
      ->selected(module::get_var("tag_graph", "sort_order"), "ALPHA");
	$group->input("tagcolor")    ->label(t("Tag color"))
      ->value(module::get_var("tag_graph", "tagcolor", "5555ff"))
      ->error_message("not_valid", t("The color value must be specified as 'rrggbb'"))
      ->rules("required|length[6]");
    $group->input("mouseover")    ->label(t("Tag mouseover color"))
      ->value(module::get_var("tag_graph", "mouseover", "b1b1b1"))
      ->error_message("not_valid", t("The color value must be specified as 'rrggbb'"))
      ->rules("required|length[6]");
    $group->input("show_above")->label(t("Show tags above this weight."))
      ->value(module::get_var("tag_graph", "show_above", "0"))
      ->rules("required|valid_numeric|length[1,4]");
	$group->input("show_below")->label(t("Show tags below this weight."))
      ->value(module::get_var("tag_graph", "show_below", "500"))
      ->rules("required|valid_numeric|length[1,4]");
	$group->input("height")->label(t("Height of list (pixels).  Scroll bar will be added if necessary.  Default of 0 will alow it to fit as needed."))
      ->value(module::get_var("tag_graph", "height", "0"))
      ->rules("required|valid_numeric|length[1,4]");

    $group->submit("")->value(t("Save"));

    return $form;
  }
}
